@@ -7,27 +7,11 @@ from django.shortcuts import redirect
 from django.urls import reverse
 
 from network.base.models import Antenna, AntennaType, DemodData, \
-    FrequencyRange, Observation, Satellite, Station, StationAntenna, Tle, \
-    Transmitter
+    FrequencyRange, Observation, Satellite, Station, Tle, Transmitter
 from network.base.tasks import sync_to_db
 from network.base.utils import export_as_csv, export_station_status
 
 
-@admin.register(Antenna)
-class AntennaAdmin(admin.ModelAdmin):
-    """Define Antenna view in django admin UI"""
-    list_display = ('id', '__str__', 'antenna_count', 'station_list')
-    list_filter = ('band', 'antenna_type')
-
-    def antenna_count(self, obj):  # pylint: disable=no-self-use
-        """Return the number of antennas"""
-        return obj.stations.all().count()
-
-    def station_list(self, obj):  # pylint: disable=no-self-use
-        """Return stations that use the antenna"""
-        return ",\n".join([str(s.id) for s in obj.stations.all()])
-
-
 @admin.register(FrequencyRange)
 class FrequenyRangeAdmin(admin.ModelAdmin):
     """Define Frequency Range view in django admin UI"""
@@ -43,7 +27,7 @@ class FrequenyRangeAdmin(admin.ModelAdmin):
 
     def formfield_for_foreignkey(self, db_field, request, **kwargs):
         if db_field.name == "antenna":
-            kwargs["queryset"] = StationAntenna.objects.order_by('station_id')
+            kwargs["queryset"] = Antenna.objects.order_by('station_id')
         return super(FrequenyRangeAdmin,
                      self).formfield_for_foreignkey(db_field, request, **kwargs)
 
@@ -55,19 +39,19 @@ class AntennaTypeAdmin(admin.ModelAdmin):
 
     def antenna_count(self, obj):  # pylint: disable=no-self-use
         """Return the number of antennas use this antenna type"""
-        return obj.station_antennas.all().count()
+        return obj.antennas.all().count()
 
     def antenna_list(self, obj):  # pylint: disable=no-self-use
         """Return antennas that use the antenna type"""
-        return ",\n".join([str(s.id) for s in obj.station_antennas.all().order_by('id')])
+        return ",\n".join([str(s.id) for s in obj.antennas.all().order_by('id')])
 
     def station_list(self, obj):  # pylint: disable=no-self-use
         """Return antennas that use the antenna type"""
-        return ",\n".join([str(s.station.id) for s in obj.station_antennas.all().order_by('id')])
+        return ",\n".join([str(s.station.id) for s in obj.antennas.all().order_by('id')])
 
 
-@admin.register(StationAntenna)
-class StationAntennaAdmin(admin.ModelAdmin):
+@admin.register(Antenna)
+class AntennaAdmin(admin.ModelAdmin):
     """Define Antenna Type view in django admin UI"""
     list_display = ('id', 'antenna_type', 'station', 'ranges_list')
 
@@ -85,8 +69,7 @@ class StationAntennaAdmin(admin.ModelAdmin):
     def formfield_for_foreignkey(self, db_field, request, **kwargs):
         if db_field.name == "station":
             kwargs["queryset"] = Station.objects.order_by('id')
-        return super(StationAntennaAdmin,
-                     self).formfield_for_foreignkey(db_field, request, **kwargs)
+        return super(AntennaAdmin, self).formfield_for_foreignkey(db_field, request, **kwargs)
 
 
 @admin.register(Station)
