@@ -5,7 +5,6 @@ import codecs
 import logging
 import os
 import re
-import struct
 from datetime import timedelta
 
 import requests
@@ -15,7 +14,6 @@ from django.core.exceptions import ValidationError
 from django.core.validators import MaxValueValidator, MinValueValidator
 from django.db import models
 from django.db.models import OuterRef, Subquery
-from django.db.models.signals import post_save
 from django.dispatch import receiver
 from django.urls import reverse
 from django.utils.encoding import python_2_unicode_compatible
@@ -24,30 +22,11 @@ from django.utils.timezone import now
 from PIL import Image
 from rest_framework.authtoken.models import Token
 from shortuuidfield import ShortUUIDField
-from tinytag import TinyTag, TinyTagException
 
 from network.base.managers import ObservationManager
 from network.base.utils import bands_from_range
 from network.users.models import User
 
-ANTENNA_BANDS = ['HF', 'VHF', 'UHF', 'L', 'S', 'C', 'X', 'KU']
-ANTENNA_TYPES = (
-    ('dipole', 'Dipole'),
-    ('v-dipole', 'V-Dipole'),
-    ('discone', 'Discone'),
-    ('ground', 'Ground Plane'),
-    ('yagi', 'Yagi'),
-    ('cross-yagi', 'Cross Yagi'),
-    ('helical', 'Helical'),
-    ('parabolic', 'Parabolic'),
-    ('vertical', 'Vertical'),
-    ('turnstile', 'Turnstile'),
-    ('quadrafilar', 'Quadrafilar'),
-    ('eggbeater', 'Eggbeater'),
-    ('lindenblad', 'Lindenblad'),
-    ('paralindy', 'Parasitic Lindenblad'),
-    ('patch', 'Patch')  # yapf: disable
-)
 OBSERVATION_STATUSES = (
     ('unknown', 'Unknown'),
     ('good', 'Good'),
@@ -82,69 +61,6 @@ def _name_obs_demoddata(instance, filename):
     return 'data_obs/{0}/{1}'.format(instance.observation.id, filename)
 
 
-def _observation_post_save(sender, instance, created, **kwargs):  # pylint: disable=W0613
-    """
-    Post save Observation operations
-    * Auto vet as good observation with DemodData
-    * Mark Observations from testing stations
-    * Update client version for ground station
-    """
-    post_save.disconnect(_observation_post_save, sender=Observation)
-    if instance.has_audio and not instance.archived:
-        try:
-            audio_metadata = TinyTag.get(instance.payload.path)
-            # Remove audio if it is less than 1 sec
-            if audio_metadata.duration is None or audio_metadata.duration < 1:
-                instance.payload.delete()
-        except TinyTagException:
-            # Remove invalid audio file
-            instance.payload.delete()
-        except (struct.error, TypeError):
-            # Remove audio file with wrong structure
-            instance.payload.delete()
-    if created and instance.ground_station.testing:
-        instance.testing = True
-        instance.save()
-    if instance.has_demoddata and instance.vetted_status == 'unknown':
-        instance.vetted_status = 'good'
-        instance.vetted_datetime = now()
-        instance.save()
-    post_save.connect(_observation_post_save, sender=Observation)
-
-
-def _station_post_save(sender, instance, created, **kwargs):  # pylint: disable=W0613
-    """
-    Post save Station operations
-    * Store current status
-    """
-    post_save.disconnect(_station_post_save, sender=Station)
-    if not created:
-        current_status = instance.status
-        if instance.is_offline:
-            instance.status = 0
-        elif instance.testing:
-            instance.status = 1
-        else:
-            instance.status = 2
-        instance.save()
-        if instance.status != current_status:
-            StationStatusLog.objects.create(station=instance, status=instance.status)
-    else:
-        StationStatusLog.objects.create(station=instance, status=instance.status)
-    post_save.connect(_station_post_save, sender=Station)
-
-
-def _tle_post_save(sender, instance, created, **kwargs):  # pylint: disable=W0613
-    """
-    Post save Tle operations
-    * Update TLE for future observations
-    """
-    if created:
-        start = now() + timedelta(minutes=10)
-        Observation.objects.filter(satellite=instance.satellite, start__gt=start) \
-                           .update(tle=instance.id)
-
-
 def validate_image(fieldfile_obj):
     """Validates image size"""
     filesize = fieldfile_obj.file.size
@@ -153,20 +69,6 @@ def validate_image(fieldfile_obj):
         raise ValidationError("Max file size is %sMB" % str(megabyte_limit))
 
 
-@python_2_unicode_compatible
-class Antenna(models.Model):
-    """Model for antennas tracked with SatNOGS."""
-    frequency = models.PositiveIntegerField()
-    frequency_max = models.PositiveIntegerField()
-    band = models.CharField(choices=list(zip(ANTENNA_BANDS, ANTENNA_BANDS)), max_length=5)
-    antenna_type = models.CharField(choices=ANTENNA_TYPES, max_length=15)
-
-    def __str__(self):
-        return '{0} - {1} - {2} - {3}'.format(
-            self.band, self.antenna_type, self.frequency, self.frequency_max
-        )
-
-
 @python_2_unicode_compatible
 class Station(models.Model):
     """Model for SatNOGS ground stations."""
@@ -184,16 +86,6 @@ class Station(models.Model):
     )
     # https://en.wikipedia.org/wiki/Maidenhead_Locator_System
     qthlocator = models.CharField(max_length=8, blank=True)
-    antenna = models.ManyToManyField(
-        Antenna,
-        blank=True,
-        related_name="stations",
-        help_text=(
-            'If you want to add a new Antenna contact '
-            '<a href="https://community.satnogs.org/" '
-            'target="_blank">SatNOGS Team</a>'
-        )
-    )
     featured_date = models.DateField(null=True, blank=True)
     created = models.DateTimeField(auto_now_add=True)
     testing = models.BooleanField(default=True)
@@ -301,9 +193,6 @@ class Station(models.Model):
             )
 
 
-post_save.connect(_station_post_save, sender=Station)
-
-
 @python_2_unicode_compatible
 class AntennaType(models.Model):
     """Model for antenna types."""
@@ -314,10 +203,10 @@ class AntennaType(models.Model):
 
 
 @python_2_unicode_compatible
-class StationAntenna(models.Model):
+class Antenna(models.Model):
     """Model for antennas of SatNOGS ground stations."""
     antenna_type = models.ForeignKey(
-        AntennaType, on_delete=models.PROTECT, related_name='station_antennas'
+        AntennaType, on_delete=models.PROTECT, related_name='antennas'
     )
     station = models.ForeignKey(Station, on_delete=models.CASCADE, related_name='antennas')
 
@@ -343,9 +232,7 @@ class StationAntenna(models.Model):
 @python_2_unicode_compatible
 class FrequencyRange(models.Model):
     """Model for frequency ranges of antennas."""
-    antenna = models.ForeignKey(
-        StationAntenna, on_delete=models.CASCADE, related_name='frequency_ranges'
-    )
+    antenna = models.ForeignKey(Antenna, on_delete=models.CASCADE, related_name='frequency_ranges')
     min_frequency = models.BigIntegerField()
     max_frequency = models.BigIntegerField()
 
@@ -460,9 +347,6 @@ class Tle(models.Model):
         return [str(self.tle0), str(self.tle1), str(self.tle2)]
 
 
-post_save.connect(_tle_post_save, sender=Tle)
-
-
 class LatestTleManager(models.Manager):  # pylint: disable=R0903
     """Django Manager for latest Tle objects"""
     def get_queryset(self):
@@ -667,9 +551,6 @@ def observation_remove_files(sender, instance, **kwargs):  # pylint: disable=W06
             os.remove(instance.waterfall.path)
 
 
-post_save.connect(_observation_post_save, sender=Observation)
-
-
 @python_2_unicode_compatible
 class DemodData(models.Model):
     """Model for DemodData."""
