@@ -22,6 +22,12 @@ from network.base.models import DemodData, LatestTle, Observation, Satellite, \
 from network.base.utils import sync_demoddata_to_db
 
 
+def delay_task_with_lock(task, lock_id, lock_expiration, *args):
+    """Ensure unique run of a task by aquiring lock"""
+    if cache.add('{0}-{1}'.format(task.name, lock_id), '', lock_expiration):
+        task.delay(*args)
+
+
 @shared_task
 def update_all_tle():
     """Task to update all satellite TLEs"""
@@ -200,17 +206,20 @@ def clean_observations():
 
 
 @shared_task
-def sync_to_db():
+def sync_to_db(frame_id=None):
     """Task to send demod data to SatNOGS DB / SiDS"""
     transmitters = Transmitter.objects.filter(sync_to_db=True).values_list('uuid', flat=True)
 
     frames = DemodData.objects.filter(
         copied_to_db=False, observation__transmitter_uuid__in=transmitters
     )
+
+    if frame_id:
+        frames = frames.filter(pk=frame_id)[:1]
+
     for frame in frames:
         if frame.is_image() or frame.copied_to_db or not os.path.isfile(frame.payload_demod.path):
             continue
-
         try:
             sync_demoddata_to_db(frame)
         except requests.exceptions.RequestException:
